$ifndef __SPI_INC_
$define __SPI_INC_
'
' SPI Peripheral Macros
'
' For 18F devices using version 3.4.0.6 onwards of the Proton Compiler
' This file is supplied as-is and without warranty.
'
' It is encouraged that devices that are not supported be added by the users
' of the Proton compiler and made available on the Proton forum.
' www.protonbasic.co.uk
'
' However, do not Modify unless you are absolutely sure of what you are doing.
'
$if (_core <> 16)
    $error "Timer Macros only For use with 18F devices"
$endif

Include "SPIdefs.inc"

'-----------------------------------------------------------------------------------
' Macro Name    OpenSPI
' Return Value  : None
' Parameters    : SSP peripheral setup values
' Notes         : Sets up the SSP module for master or slave operation
'
' Syntax OpenSPI pSyncMode , pBusMode , pSmpPhase
'
$if _defined (SPI_V1)

$define OpenSPI(pS,pB,pSP) _OpenSPI pS, pB, pSP

_OpenSPI Macro- pSyncMode , pBusMode , pSmpPhase

    SSPSTAT = SSPSTAT & $3F         ' Power on state
    SSPCON1 = $00                   ' Power on state
    #if(pSyncMode != 0)
        movlw (pSyncMode)
        iorwf SSPCON1,f             ' Select serial mode
    #endif
    #if(pSmpPhase != 0)
        movlw (pSmpPhase)
        iorwf SSPSTAT,f             ' Select data input sample phase
    #endif

    #if(pBusMode == 0)              ' SPI bus mode 0,0
        SSPSTATbits_CKE = 1         ' Data transmitted on rising edge
    #endif
    #if(pBusMode == 2)              ' SPI bus mode 1,0
        SSPSTATbits_CKE = 1         ' Data transmitted on falling edge
        SSPCON1bits_CKP = 1         ' Clock idle state high
    #endif
    #if(pBusMode == 3)              ' SPI bus mode 1,1
        SSPCON1bits_CKP = 1         ' Clock idle state high
    #endif

    #if(pSyncMode == 4)             ' Slave mode with /SS enable
    $if _defined (SPI_IO_V1)
      TRISC.3 = 1                   ' define clock pin as input
      TRISA.5 = 1                   ' define /SS1 pin as input
    $elseif _defined (SPI_IO_V2) Or _defined (SPI_IO_V4)
      TRISF.7 = 1                   ' define /SS pin as input
      TRISC.3 = 1                   ' define clock pin as input
    $elseif _defined (SPI_IO_V3)
      TRISA.5 = 1                   ' define /SS pin as input
      TRISB.1 = 1                   ' define clock pin as input
    $elseif _defined (SPI_IO_V5)
      TRISC.6 = 1                   ' define /SS pin as input
      TRISC.5 = 1                   ' define clock pin as input
    $elseif _defined (SPI_IO_V6)
      TRISC.3 = 1                   ' define clock pin as input
      TRISA.5 = 1                   ' define /SS1 pin as input
      ANSEL = ANSEL & %11101111
    $elseif _defined (SPI_IO_V9)
      TRISB.6 = 1                   ' define clock pin as input
      TRISC.6 = 1                   ' define /SS pin as input
    $endif
    #endif

    #if(pSyncMode == 5)             ' Slave mode withouto /SS enable
    $if _defined (SPI_IO_V1) Or _defined (SPI_IO_V6) Or _defined (SPI_IO_V2) Or _defined (SPI_IO_V4)
      TRISC.3 = 1                   ' define clock pin as input
    $elseif _defined (SPI_IO_V3)
      TRISB.1 = 1                   ' define clock pin as input
    $elseif _defined (SPI_IO_V5)
      TRISC.5 = 1                   ' define clock pin as input
    $elseif _defined (SPI_IO_V9)
      TRISB.6 = 1                   ' define clock pin as input
    $endif
    #else                           ' Master mode, define clock pin as output
    $if _defined (SPI_IO_V1) Or _defined (SPI_IO_V6) Or _defined (SPI_IO_V2) Or _defined (SPI_IO_V4)
      TRISC.3 = 0                   ' define clock pin as input
    $elseif _defined (SPI_IO_V3)
      TRISB.1 = 0                   ' define clock pin as input
    $elseif _defined (SPI_IO_V5)
      TRISC.5 = 0                   ' define clock pin as input
    $elseif _defined (SPI_IO_V9)
      TRISB.6 = 0                   ' define clock pin as output
    $endif
    #endif

    $if _defined (SPI_IO_V3)
      TRISB.0 = 1                   ' define SDI pin as input
      TRISC.7 = 0                   ' define SDO pin as output
    $elseif _defined (SPI_IO_V5)
      TRISC.4 = 1                   ' define SDI pin as input
      TRISC.7 = 0                   ' define SDO pin as output
    $elseif _defined (SPI_IO_V9)
      TRISC.7 = 0                   ' define SDO pin as output
      TRISB.4 = 1                   ' define SDI pin as input
    $else
      TRISC.4 = 1                   ' define SDI pin as input
      TRISC.5 = 0                   ' define SDO pin as output
    $endif
    SSPCON1 = SSPCON1 | SSPENB      ' Enable synchronous serial port
    Endm
$endif
$if _defined (SPI_V4)

$define OpenSPI(pS,pB,pSP) _OpenSPI pS, pB, pSP
_OpenSPI Macro- pSyncMode , pBusMode , pSmpPhase

    SSPSTAT = SSPSTAT & $3F         ' Power on state
    SSPCON = $00                    ' Power on state
    #if(pSyncMode != 0)
        movlw (pSyncMode)
        iorwf SSPCON,f              ' Select serial mode
    #endif
    #if(pSmpPhase != 0)
        movlw (pSmpPhase)
        iorwf SSPSTAT,f             ' Select data input sample phase
    #endif

    #if(pBusMode == 0)              ' SPI bus mode 0,0
        SSPSTATbits_CKE = 1         ' Data transmitted on rising edge
    #endif
    #if(pBusMode == 2)              ' SPI bus mode 1,0
        SSPSTATbits_CKE = 1         ' Data transmitted on falling edge
        SSPCONbits_CKP = 1          ' Clock idle state high
    #endif
    #if(pBusMode == 3)              ' SPI bus mode 1,1
        SSPCONbits_CKP = 1          ' Clock idle state high
    #endif

    #if(pSyncMode == 4)             ' Slave mode with /SS enable
    $if _defined (SPI_IO_V1)
      TRISC.3 = 1                   ' define clock pin as input
      TRISA.5 = 1                   ' define /SS1 pin as input
    $elseif _defined (SPI_IO_V2) Or _defined (SPI_IO_V4)
      TRISF.7 = 1                   ' define /SS pin as input
      TRISC.3 = 1                   ' define clock pin as input
    $elseif _defined (SPI_IO_V3)
      TRISA.5 = 1                   ' define /SS pin as input
      TRISB.1 = 1                   ' define clock pin as input
    $elseif _defined (SPI_IO_V5)
      TRISC.6 = 1                   ' define /SS pin as input
      TRISC.5 = 1                   ' define clock pin as input
    $elseif _defined (SPI_IO_V6 )
      TRISC.3 = 1                   ' define clock pin as input
      TRISA.5 = 1                   ' define /SS1 pin as input
      ANSEL = ANSEL & %11101111
    $endif
    #endif

    #if(pSyncMode == 5)             ' Slave mode withouto /SS enable
    $if _defined (SPI_IO_V1) Or _defined (SPI_IO_V6) Or _defined (SPI_IO_V2) Or _defined (SPI_IO_V4)
      TRISC.3 = 1                   ' define clock pin as input
    $elseif _defined (SPI_IO_V3)
      TRISB.1 = 1                   ' define clock pin as input
    $elseif _defined (SPI_IO_V5 )
      TRISC.5 = 1                   ' define clock pin as input
    $endif
    #else                           ' Master mode, define clock pin as output
    $if _defined (SPI_IO_V1) Or _defined (SPI_IO_V6) Or _defined (SPI_IO_V2) Or _defined (SPI_IO_V4)
      TRISC.3 = 0                   ' define clock pin as input
    $elseif _defined (SPI_IO_V3)
      TRISB.1 = 0                   ' define clock pin as input
    $elseif _defined (SPI_IO_V5)
      TRISC.5 = 0                   ' define clock pin as input
    $endif
    #endif

    $if _defined (SPI_IO_V3)
      TRISB.0 = 1                   ' define SDI pin as input
      TRISC.7 = 0                   ' define SDO pin as output
    $elseif _defined (SPI_IO_V5)
      TRISC.4 = 1                   ' define SDI pin as input
      TRISC.7 = 0                   ' define SDO pin as output
    $else
      TRISC.4 = 1                   ' define SDI pin as input
      TRISC.5 = 0                   ' define SDO pin as output
    $endif
    SSPCON = SSPCON | SSPENB        ' Enable synchronous serial port
    Endm
$endif
'-----------------------------------------------------------------------------------
' Macro Name    OpenSPI1
' Return Value  : None
' Parameters    : SSP1 peripheral setup values
' Notes         : Sets up the SSP1 module for master or slave operation
'
' Syntax OpenSPI1 pSyncMode , pBusMode , pSmpPhase
'
$if _defined (SPI_V2) Or _defined (SPI_V3)

$define OpenSPI1(pS,pB,pSP) _OpenSPI1 pS, pB, pSP
_OpenSPI1 Macro- pSyncMode , pBusMode , pSmpPhase

    SSP1STAT = SSP1STAT & $3F       ' Power on state
    SSP1CON1 = $00                   ' Power on state
    #if(pSyncMode != 0)
        movlw (pSyncMode)
        iorwf SSP1CON1,f             ' Select serial mode
    #endif
    #if(pSmpPhase != 0)
        movlw (pSmpPhase)
        iorwf SSP1STAT,f            ' Select data input sample phase
    #endif

    #if(pBusMode == 0)              ' SPI bus mode 0,0
        SSP1STATbits_CKE = 1        ' Data transmitted on rising edge
    #endif
    #if(pBusMode == 2)              ' SPI bus mode 1,0
        SSP1STATbits_CKE = 1        ' Data transmitted on falling edge
        SSP1CON1bits_CKP = 1        ' Clock idle state high
    #endif
    #if(pBusMode == 3)              ' SPI bus mode 1,1
        SSP1CON1bits_CKP = 1        ' Clock idle state high
    #endif

    #if(pSyncMode == 4)             ' Slave mode with /SS enable
    $if _defined (SPI_IO_V1)
      TRISC.3 = 1                   ' define clock pin as input
      TRISA.5 = 1                   ' define /SS1 pin as input
    $elseif _defined (SPI_IO_V2)
      TRISF.7 = 1                   ' define /SS1 pin as input
      TRISC.3 = 1                   ' define clock pin as input
    $endif
    #endif

    #if(pSyncMode == 5)             ' slave mode without /SS enable
      TRISC.3 = 1                   ' define clock pin as input
    #else                           ' master mode, define clock pin as output
      TRISC.3 = 0                   ' define clock pin as input
    #endif
    TRISC.4 = 1                     ' define SDI pin as input
    TRISC.5 = 0                     ' define SDO pin as output

    SSP1CON1 = SSP1CON1 | SSPENB    ' enable synchronous serial port
Endm
$endif
$if _defined (SPI_V5)

$define OpenSPI1(pS,pB,pSP) _OpenSPI1 pS, pB, pSP
_OpenSPI1 Macro- pSyncMode , pBusMode , pSmpPhase

    SSP1STAT = SSP1STAT & $3F       ' Power on state
    SSP1CON1 = $00                   ' Power on state
    #if(pSyncMode != 0)
        movlw (pSyncMode)
        iorwf SSP1CON1,f             ' Select serial mode
    #endif
    #if(pSmpPhase != 0)
        movlw (pSmpPhase)
        iorwf SSP1STAT,f            ' Select data input sample phase
    #endif

    #if(pBusMode == 0)              ' SPI bus mode 0,0
        SSP1STATbits_CKE = 1        ' Data transmitted on rising edge
    #endif
    #if(pBusMode == 2)              ' SPI bus mode 1,0
        SSP1STATbits_CKE = 1        ' Data transmitted on falling edge
        SSP1CON1bits_CKP = 1        ' Clock idle state high
    #endif
    #if(pBusMode == 3)              ' SPI bus mode 1,1
        SSP1CON1bits_CKP = 1         ' Clock idle state high
    #endif

    SSP1CON1 = SSP1CON1 | SSPENB    ' enable synchronous serial port
Endm
$endif
'-----------------------------------------------------------------------------------
' Macro Name    OpenSPI2
' Return Value  : None
' Parameters    : SSP2 peripheral setup values
' Notes         : Sets up the SSP2 module for master or slave operation
'
' Syntax OpenSPI2 pSyncMode , pBusMode , pSmpPhase
'
$if _defined (SPI_V3)

$define OpenSPI2(pS,pB,pSP) _OpenSPI2 pS, pB, pSP
_OpenSPI2 Macro- pSyncMode , pBusMode , pSmpPhase

    SSP2STAT = SSP2STAT & $3F       ' Power on state
    SSP2CON1 = $00                  ' Power on state
    #if(pSyncMode != 0)
        movlw (pSyncMode)
        iorwf SSP2CON1,f            ' Select serial mode
    #endif
    #if(pSmpPhase != 0)
        movlw (pSmpPhase)
        iorwf SSP2STAT,f            ' Select data input sample phase
    #endif

    #if(pBusMode == 0)              ' SPI bus mode 0,0
        SSP2STATbits_CKE = 1        ' Data transmitted on rising edge
    #endif
    #if(pBusMode == 2)              ' SPI bus mode 1,0
        SSP2STATbits_CKE = 1        ' Data transmitted on falling edge
        SSP2CON1bits_CKP = 1        ' Clock idle state high
    #endif
    #if(pBusMode == 3)              ' SPI bus mode 1,1
        SSP2CON1bits_CKP = 1        ' Clock idle state high
    #endif

    #if(pSyncMode == 4)             ' Slave mode with /SS enable
    $if _defined (SPI_IO_V8)
      TRISD.3 = 1                   ' define /SS2 pin as input
      TRISD.0 = 1                   ' define clock pin as input
    $else
      TRISD.7 = 1                   ' define /SS1 pin as input
      TRISD.6 = 1                   ' define clock pin as input
    $endif
    #endif

    #if(pSyncMode == 5)             ' slave mode without /SS enable
    $if _defined (SPI_IO_V8)
      TRISD.0 = 1                   ' define clock pin as input
    $else
      TRISD.6 = 1                   ' define clock pin as input
    $endif
    #else                           ' master mode, define clock pin as output
    $if _defined (SPI_IO_V8)
      TRISD.0 = 0                   ' define clock pin as input
    $else
      TRISD.6 = 0                   ' define clock pin as input
    $endif
    #endif

    $if _defined (SPI_IO_V8)
      TRISD.1 = 1                   ' define SDI pin as input
      TRISD.2 = 0                   ' define SDO pin as output
    $else
      TRISD.5 = 1                   ' define SDI pin as input
      TRISD.4 = 0                   ' define SDO pin as output
    $endif

    SSP2CON1 = SSP2CON1 | SSPENB    ' enable synchronous serial port
    Endm
$endif
$if _defined (SPI_V5)

$define OpenSPI2(pS,pB,pSP) _OpenSPI2 pS, pB, pSP
_OpenSPI2 Macro- pSyncMode , pBusMode , pSmpPhase

    SSP2STAT = SSP2STAT & $3F       ' Power on state
    SSP2CON1 = $00                  ' Power on state
    #if(pSyncMode != 0)
        movlw (pSyncMode)
        iorwf SSP2CON1,f            ' Select serial mode
    #endif
    #if(pSmpPhase != 0)
        movlw (pSmpPhase)
        iorwf SSP2STAT,f            ' Select data input sample phase
    #endif

    #if(pBusMode == 0)              ' SPI bus mode 0,0
        SSP2STATbits_CKE = 1        ' Data transmitted on rising edge
    #endif
    #if(pBusMode == 2)              ' SPI bus mode 1,0
        SSP2STATbits_CKE = 1        ' Data transmitted on falling edge
        SSP2CON1bits_CKP = 1        ' Clock idle state high
    #endif
    #if(pBusMode == 3)              ' SPI bus mode 1,1
        SSP2CON1bits_CKP = 1        ' Clock idle state high
    #endif

    SSP2CON1 = SSP2CON1 | SSPENB    ' enable synchronous serial port
    Endm
$endif
'-----------------------------------------------------------------------------------
' Macro Name    WriteSPI
' Return Value   :
' Parameter      : Single 8-bit variable for SPI bus.
' Description    : Write a single byte (8-bits) to the SPI bus.
'
$if _defined (SPI_V1) Or _defined (SPI_V4)
$define WriteSPI(pDataOut) WREG = SSPBUF : PIR1bits_SSPIF = 0 : SSPBUF = pDataOut : btfss PIR1bits_SSPIF : bra ($ - 2)

$endif
'-----------------------------------------------------------------------------------
' Macro Name    WriteSPI1
' Return Value   :
' Parameter      : Single 8-bit variable for SPI1 bus.
' Description    : Write a single byte (8-bits) to the SPI1 bus.
'
$if _defined (SPI_V2) Or _defined (SPI_V3) Or _defined (SPI_V5)
$define WriteSPI1(pDataOut) WREG = SSP1BUF : PIR1bits_SSP1IF = 0 : SSP1BUF = pDataOut : btfss PIR1bits_SSP1IF : bra ($ - 2)

$endif
'-----------------------------------------------------------------------------------
' Macro Name    WriteSPI2
' Return Value   :
' Parameter      : Single 8-bit variable for SPI2 bus.
' Description    : Write a single byte (8-bits) to the SPI2 bus.
'
$if _defined (SPI_V3) Or _defined (SPI_V5)
$define WriteSPI2(pDataOut) WREG = SSP2BUF : PIR3bits_SSP2IF = 0 : SSP2BUF = pDataOut : btfss PIR3bits_SSP2IF : bra ($ - 2)

$endif
'-----------------------------------------------------------------------------------
' Macro Name    : ReadSPI
' Return Value  : Contents of SSPBUF register
' Parameters    : None
' Description   : Read byte\s from the SPI bus.
'
$if _defined (SPI_V1) Or _defined (SPI_V4)

$define ReadSPI() _ReadSPI
_ReadSPI Macro- \Byte
    WREG = SSPBUF                           ' Clears BF
    PIR1bits_SSPIF = 0                      ' Clear interrupt flag
    SSPBUF = $00                            ' initiate bus cycle
    btfss PIR1bits_SSPIF
    bra $ - 2                               ' Wait until cycle complete
    #if(_ReadSPI_Return == 1)
        #if(Return_Type == Byte)
            #if((Return_Var == WREG) || (Return_Var == SSPBUF))
                movf SSPBUF,W
            #else
                Byte_Byte SSPBUF,Return_Var
            #endif
        #endif
        #if(Return_Type == Word)
            Byte_Byte SSPBUF,Return_Var
            btfss PIR1bits_SSPIF
            bra $ - 2                       ' Wait until cycle complete
            Byte_Byte SSPBUF,Return_Var + 1
        #endif
        #if(Return_Type == Dword)
            Byte_Byte SSPBUF,Return_Var
            btfss PIR1bits_SSPIF
            bra $ - 2                       ' Wait until cycle complete
            Byte_Byte SSPBUF,Return_Var + 1
            btfss PIR1bits_SSPIF
            bra $ - 2                       ' Wait until cycle complete
            Byte_Byte SSPBUF,Return_Var + 2
            btfss PIR1bits_SSPIF
            bra $ - 2                       ' Wait until cycle complete
            Byte_Byte SSPBUF,Return_Var + 3
        #endif
    #endif
    Endm
$endif
'-----------------------------------------------------------------------------------
' Macro Name    : ReadSPI1
' Return Value  : Contents of SSPBUF1 register
' Parameters    : None
' Description   : Read byte\s from the SPI1 bus.
'
$if _defined (SPI_V2) Or _defined (SPI_V3) Or _defined (SPI_V5)

$define ReadSPI1() _ReadSPI1
_ReadSPI1 Macro- \Byte
    WREG = SSP1BUF                          ' Clears BF
    PIR1bits_SSP1IF = 0                     ' Clear interrupt flag
    SSP1BUF = $00                           ' initiate bus cycle
    btfss PIR1bits_SSP1IF
    bra $ - 2                               ' Wait until cycle complete
    #if(_ReadSPI1_Return == 1)
        #if(Return_Type == Byte)
            #if((Return_Var == WREG) || (Return_Var == SSP1BUF))
                movf SSP1BUF,W
            #else
                Byte_Byte SSP1BUF,Return_Var
            #endif
        #endif
        #if(Return_Type == Word)
            Byte_Byte SSP1BUF,Return_Var
            btfss PIR1bits_SSP1IF
            bra $ - 2                       ' Wait until cycle complete
            Byte_Byte SSP1BUF,Return_Var + 1
        #endif
        #if(Return_Type == Dword)
            Byte_Byte SSP1BUF,Return_Var
            btfss PIR1bits_SSP1IF
            bra $ - 2                       ' Wait until cycle complete
            Byte_Byte SSP1BUF,Return_Var + 1
            btfss PIR1bits_SSP1IF
            bra $ - 2                       ' Wait until cycle complete
            Byte_Byte SSP1BUF,Return_Var + 2
            btfss PIR1bits_SSP1IF
            bra $ - 2                       ' Wait until cycle complete
            Byte_Byte SSP1BUF,Return_Var + 3
        #endif
    #endif
    Endm
$endif
'-----------------------------------------------------------------------------------
' Macro Name    : ReadSPI2
' Return Value  : Contents of SSPBUF2 register
' Parameters    : None
' Description   : Read byte\s from the SPI2 bus.
'
$if _defined (SPI_V3) Or _defined (SPI_V5)

$define ReadSPI2() _ReadSPI2
_ReadSPI2 Macro- \Byte
    WREG = SSP2BUF                          ' Clears BF
    PIR3bits_SSP2IF = 0                     ' Clear interrupt flag
    SSP2BUF = $00                           ' initiate bus cycle
    btfss PIR3bits_SSP2IF
    bra $ - 2                               ' Wait until cycle complete
    #if(_ReadSPI2_Return == 1)
        #if(Return_Type == Byte)
            #if((Return_Var == WREG) || (Return_Var == SSP2BUF))
                movf SSP2BUF,W
            #else
                Byte_Byte SSP2BUF,Return_Var
            #endif
        #endif
        #if(Return_Type == Word)
            Byte_Byte SSP2BUF,Return_Var
            btfss PIR3bits_SSP2IF
            bra $ - 2                       ' Wait until cycle complete
            Byte_Byte SSP2BUF,Return_Var + 1
        #endif
        #if(Return_Type == Dword)
            Byte_Byte SSP2BUF,Return_Var
            btfss PIR3bits_SSP2IF
            bra $ - 2                       ' Wait until cycle complete
            Byte_Byte SSP2BUF,Return_Var + 1
            btfss PIR3bits_SSP2IF
            bra $ - 2                       ' Wait until cycle complete
            Byte_Byte SSP2BUF,Return_Var + 2
            btfss PIR3bits_SSP2IF
            bra $ - 2                       ' Wait until cycle complete
            Byte_Byte SSP2BUF,Return_Var + 3
        #endif
    #endif
Endm
$endif

$endif
