$ifndef __SPIDEFS_INC_
$define __SPIDEFS_INC_

Include "pconfig.inc"

(* PIC18 SPI peripheral library header *)
' This file is supplied as-is and without warranty.
'
' It is encouraged that devices that are not supported be added by the users
' of the Proton compiler and made available on the Proton forum.
' www.protonbasic.co.uk
'
' However, do not Modify unless you are absolutely sure of what you are doing.
'

(* SSPSTAT REGISTER *)

' Master SPI mode only

$define SMPEND        %10000000          ' Input data sample at end of data out
$define SMPMID        %00000000          ' Input data sample at middle of data out

$define MODE_00       %00000000          ' Setting for SPI bus Mode 0,0
$define MODE_01       %00000001          ' Setting for SPI bus Mode 0,1
$define MODE_10       %00000010          ' Setting for SPI bus Mode 1,0
$define MODE_11       %00000011          ' Setting for SPI bus Mode 1,1

(* SSPCON1 REGISTER *)
$define SSPENB        %00100000          ' Enable serial port and configures SCK, SDO, SDI

$define SPI_FOSC_4    %00000000          ' SPI Master mode, clock = Fosc/4
$define SPI_FOSC_16   %00000001          ' SPI Master mode, clock = Fosc/16
$define SPI_FOSC_64   %00000010          ' SPI Master mode, clock = Fosc/64
$define SPI_FOSC_TMR2 %00000011          ' SPI Master mode, clock = TMR2 output/2
$define SLV_SSON      %00000100          ' SPI Slave mode, /SS pin control enabled
$define SLV_SSOFF     %00000101          ' SPI Slave mode, /SS pin control disabled
(************************************************************************************************)

(*  25Cxxx EEPROM instruction set *)
$define SPI_WREN          6              ' write enable latch
$define SPI_WRDI          4              ' reset the write enable latch
$define SPI_RDSR          5              ' read status register
$define SPI_WRSR          1              ' write status register
$define SPI_READ          3              ' read data from memory
$define SPI_WRITE         2              ' write data to memory

(*  Bits within status register of 25Cxxx *)
$define WIP           0                  ' write in progress status
$define WEL           1                  ' write enable latch status
$define BP0           2                  ' block protection bit status
$define BP1           3                  ' block protection bit status


(* These devices have two SPI modules *)
$if _defined (SPI_V2) Or _defined (SPI_V3) Or _defined (SPI_V5)

(* ***** SPI1 ***** *)
$define CloseSPI CloseSPI1

$define DataReadySPI DataReadySPI1

$define ReadSPI ReadSPI1

(* CloseSPI1: Disable SPI1 module *)
$define CloseSPI1() SSP1CON1 = SSP1CON1 & $DF

(* DataReadySPI1: Test if SSP1BUF register is full *)
$define DataReadySPI1() SSP1STATbits_BF

$define OpenSPI OpenSPI1
$define WriteSPI(pDataOut) WriteSPI1(pDataOut)

$endif
(* ***** SPI2 ***** *)

$if _defined (SPI_V3) Or _defined (SPI_V5)

(* CloseSPI2: Disable SPI2 module *)
$define CloseSPI2() SSP2CON1 = SSP2CON1 & $DF

(* DataReadySPI2: Test if SSP2BUF register is full *)
$define DataReadySPI2() SSP2STATbits_BF

$endif ' v2 and v3

$if _defined (SPI_V1) Or _defined (SPI_V4)

(* ***** SPI ***** *)

(* CloseSPI1: Disable SPI1 module *)
$if _defined (SPI_V1)
$define CloseSPI() SSPCON1 = SSPCON1 & $DF
$endif
$if _defined (SPI_V4)
$define CloseSPI() SSPCON = SSPCON & $DF
$endif

(* DataReadySPI: Test if SSPBUF register is full *)
$define DataReadySPI() SSPSTATbits_BF

$endif

$endif
