$ifndef __TimerDEFS_INC
$define __TimerDEFS_INC

Include "pconfig.Inc"

(* PIC18 timers peripheral library. *)
' This file is supplied as-is and without warranty.
'
' It is encouraged that devices that are not supported be added by the users
' of the Proton compiler and made available on the Proton forum.
' www.protonbasic.co.uk
'
' However, do not Modify unless you are absolutely sure of what you are doing.
'
(* Interrupt bit mask to be 'anded' with the other configuration masks and
 * passed as the 'pConfig' parameter to the 'open' routines. *)
$define TIMER_INT_OFF  %01111111  ' Interrupts disabled
$define TIMER_INT_ON   %11111111  ' Interrupts enabled

'-------- Timer 0 Declaration ---------------------
(* Timer0 configuration masks -- to be 'anded' together and passed to the
 * 'open' routine. *)

$define T0_16BIT       %10111111  ' Timer 0 is in 16 Bit mode
$define T0_8BIT        %11111111  ' Timer 0 is in 8 bit mode
$define T0_SOURCE_INT  %11011111  ' Internal clock source
$define T0_SOURCE_EXT  %11111111  ' External clock source
$define T0_EDGE_RISE   %11101111  ' External rising edge clocs timer
$define T0_EDGE_FALL   %11111111  ' External falling edge clocks timer
$define T0_PS_1_1      %11111111  ' Prescaler 1:1 (No Prescaler)
$define T0_PS_1_2      %11110000  '           1:2
$define T0_PS_1_4      %11110001  '           1:4
$define T0_PS_1_8      %11110010  '           1:8
$define T0_PS_1_16     %11110011  '           1:16
$define T0_PS_1_32     %11110100  '           1:32
$define T0_PS_1_64     %11110101  '           1:64
$define T0_PS_1_128    %11110110  '           1:128
$define T0_PS_1_256    %11110111  '           1:256

'-------- Timer 1 Declaration ---------------------
(* Timer1 configuration masks -- to be 'anded' together and passed to the
 * 'open' routine. *)

$if _defined (TMR_V6)

$define T1_SOURCE_PINOSC     %10011111  ' Clock source T1OSCEN = 0 Ext clock, T1OSCEN=1 Crystal osc
$define T1_SOURCE_CAPOSC     %10111111  ' Clock source is for Capacitive Sensing Oscillator
$define T1_SOURCE_FOSC_4     %11011111  ' Clock source is instruction clock (FOSC/4)
$define T1_SOURCE_FOSC       %11111111  ' Clock source is system clock (FOSC)

$define T1_PS_1_1            %11100111  ' 1:1 prescale value
$define T1_PS_1_2            %11101111  ' 1:2 prescale value
$define T1_PS_1_4            %11110111  ' 1:4 prescale value
$define T1_PS_1_8            %11111111  ' 1:8 prescale value

$define T1_OSC1EN_OFF        %11111011  ' Timer 1 oscilator enable off
$define T1_OSC1EN_ON         %11111111  ' Timer 1 oscilator enable on

$define T1_SYNC_EXT_ON      %11111101   ' Synchronise external clock input
$define T1_SYNC_EXT_OFF     %11111111   ' Do not synchronise external clock input

$define T1_8BIT_RW          %11111110   ' 8-bit mode
$define T1_16BIT_RW         %11111111   ' 16-bit mode
$else
$define T1_8BIT_RW          %10111111   ' 8-bit mode
$define T1_16BIT_RW         %11111111   ' 16-bit mode
$define T1_PS_1_1           %11001111   ' 1:1 prescale value
$define T1_PS_1_2           %11011111   ' 1:2 prescale value
$define T1_PS_1_4           %11101111   ' 1:4 prescale value
$define T1_PS_1_8           %11111111   ' 1:8 prescale value
$define T1_OSC1EN_OFF       %11110111   ' Timer 1 oscilator enable off
$define T1_OSC1EN_ON        %11111111   ' Timer 1 oscilator enable on
$define T1_SYNC_EXT_ON      %11111011   ' Synchronise external clock input
$define T1_SYNC_EXT_OFF     %11111111   ' Do not synchronise external clock input
$define T1_SOURCE_INT       %11111101   ' Internal clock source
$define T1_SOURCE_EXT       %11111111   ' External clock source

$endif

'-------- Timer 2 Declaration ---------------------
(* Timer2 configuration masks -- to be 'anded' together and passed to the
 * 'open' routine. *)

$if _defined (TMR_V2) Or _defined (TMR_V3) Or _defined (TMR_V4) Or '
    _defined (TMR_V5) Or _defined (TMR_V6)
$define T2_POST_1_1    %10000111  ' Postscaler 1:1
$define T2_POST_1_2    %10001111  ' Postscaler 1:2
$define T2_POST_1_3    %10010111  ' Postscaler 1:3
$define T2_POST_1_4    %10011111  ' Postscaler 1:4
$define T2_POST_1_5    %10100111  ' Postscaler 1:5
$define T2_POST_1_6    %10101111  ' Postscaler 1:6
$define T2_POST_1_7    %10110111  ' Postscaler 1:7
$define T2_POST_1_8    %10111111  ' Postscaler 1:8
$define T2_POST_1_9    %11000111  ' Postscaler 1:9
$define T2_POST_1_10   %11001111  ' Postscaler 1:10
$define T2_POST_1_11   %11010111  ' Postscaler 1:11
$define T2_POST_1_12   %11011111  ' Postscaler 1:12
$define T2_POST_1_13   %11100111  ' Postscaler 1:13
$define T2_POST_1_14   %11101111  ' Postscaler 1:14
$define T2_POST_1_15   %11110111  ' Postscaler 1:15
$define T2_POST_1_16   %11111111  ' Postscaler 1:16
$define T2_PS_1_1      %11111100  ' Prescale 1:1
$define T2_PS_1_4      %11111101  ' Prescale 1:4
$define T2_PS_1_16     %11111110  ' Prescale 1:16
$endif

'-------- Timer 3 Declaration ---------------------
(* Timer3 configuration masks -- to be 'anded' together and passed to the
 * 'open' routine. *)
$if _defined(TMR_V1) Or _defined(TMR_V2) Or _defined(TMR_V4)

$define T3_8BIT_RW      %11111110 ' 8-bit mode
$define T3_16BIT_RW     %11111111 ' 16-bit mode

$define T3_PS_1_1       %11001111 ' 1:1 prescale value
$define T3_PS_1_2       %11011111 ' 1:2 prescale value
$define T3_PS_1_4       %11101111 ' 1:4 prescale value
$define T3_PS_1_8       %11111111 ' 1:8 prescale value

$define T3_SYNC_EXT_ON  %11111011 ' Synchronise external clock input
$define T3_SYNC_EXT_OFF %11111111 ' Do not synchronise external clock input

$define T3_SOURCE_INT   %11111101 ' Internal clock source
$define T3_SOURCE_EXT   %11111111 ' External clock source


$elseif _defined (TMR_V6)

$define T3_SOURCE_PINOSC     %10011111  ' Clock source T1OSCEN = 0 Ext clock, T1OSCEN=1 Crystal osc
$define T3_SOURCE_CAPOSC     %10111111  ' Clock source is for Capacitive Sensing Oscillator
$define T3_SOURCE_FOSC_4     %11011111  ' Clock source is instruction clock (FOSC/4)
$define T3_SOURCE_FOSC       %11111111  ' Clock source is system clock (FOSC)

$define T3_PS_1_1            %11100111  ' 1:1 prescale value
$define T3_PS_1_2            %11101111  ' 1:2 prescale value
$define T3_PS_1_4            %11110111  ' 1:4 prescale value
$define T3_PS_1_8            %11111111  ' 1:8 prescale value

$define T3_OSC1EN_OFF        %11111011  ' Timer 1 oscilator enable off
$define T3_OSC1EN_ON         %11111111  ' Timer 1 oscilator enable on

$define T3_SYNC_EXT_ON       %11111101  ' Synchronise external clock input
$define T3_SYNC_EXT_OFF      %11111111  ' Do not synchronise external clock input

$define T3_8BIT_RW           %11111110  ' 8-bit mode
$define T3_16BIT_RW          %11111111  ' 16-bit mode

$endif

'-------- Timer 4 Declaration ---------------------
(* Timer4 configuration masks -- to be 'anded' together and passed to the
 * 'open' routine. *)
$if _defined(TMR_V4) Or _defined(TMR_V6)

$define T4_POST_1_1    %10000111  ' Postscaler 1:1
$define T4_POST_1_2    %10001111  ' Postscaler 1:2
$define T4_POST_1_3    %10010111  ' Postscaler 1:3
$define T4_POST_1_4    %10011111  ' Postscaler 1:4
$define T4_POST_1_5    %10100111  ' Postscaler 1:5
$define T4_POST_1_6    %10101111  ' Postscaler 1:6
$define T4_POST_1_7    %10110111  ' Postscaler 1:7
$define T4_POST_1_8    %10111111  ' Postscaler 1:8
$define T4_POST_1_9    %11000111  ' Postscaler 1:9
$define T4_POST_1_10   %11001111  ' Postscaler 1:10
$define T4_POST_1_11   %11010111  ' Postscaler 1:11
$define T4_POST_1_12   %11011111  ' Postscaler 1:12
$define T4_POST_1_13   %11100111  ' Postscaler 1:13
$define T4_POST_1_14   %11101111  ' Postscaler 1:14
$define T4_POST_1_15   %11110111  ' Postscaler 1:15
$define T4_POST_1_16   %11111111  ' Postscaler 1:16
$define T4_PS_1_1      %11111100  ' Prescale 1:1
$define T4_PS_1_4      %11111101  ' Prescale 1:4
$define T4_PS_1_16     %11111111  ' Prescale 1:16
$endif

'-------- Timer 5 Declaration ---------------------
$if _defined (TMR_V5)

$define T5_SLP_EN               %11111111   ' Enable during sleep
$define T5_SLP_DIS              %01111111   ' Disable during sleep

$define T5_SP_EVNT_REN          %10111111   ' special event reset enable
$define T5_SP_EVNT_RDIS         %11111111   ' special event reset disable

$define T5_MD_SNGL_SHOT         %11111111   ' Single Shot Mode
$define T5_MD_CONT_COUNT        %11011111   ' Continous Count Mode

$define T5_PS_1_1               %11100111   ' Prescale 1:1
$define T5_PS_1_2               %11101111   ' Prescale 1:2
$define T5_PS_1_4               %11110111   ' Prescale 1:4
$define T5_PS_1_8               %11111111   ' Prescale 1:8

$define T5_EX_CLK_SYNC          %11111011   ' EXT. Clock Synchronization
$define T5_EX_CLK_NOSYNC        %11111111   ' Do Not synchronise

$define T5_CLK_EXTRN            %11111111   ' Clock source external
$define T5_CLK_INT              %11111101   ' Clock source internal

$endif

$if _defined (TMR_V6)
$define TIMER_GATE_ON           %11111111   ' Timer counting is controlled by Timer1 gate function
$define TIMER_GATE_OFF          %01111111   ' Timer is always counting
$define TIMER_GATE_POL_HI       %11111111   ' Gate  is active-high
$define TIMER_GATE_POL_LO       %10111111   ' Gate is active-low
$define TIMER_GATE_TOGGLE_ON    %11111111   ' Gate Toggle mode is enabled
$define TIMER_GATE_TOGGLE_OFF   %11011111   ' Gate Toggle mode is disabled
$define TIMER_GATE_1SHOT_ON     %11111111   ' Gate one shot is enabled
$define TIMER_GATE_1SHOT_OFF    %11101111   ' Gate one shot is disabled
$define TIMER_GATE_SRC_T1GPIN   %11111100   ' Timer1 gate pin
$define TIMER_GATE_SRC_T0       %11111101   ' Timer0 overflow output
$define TIMER_GATE_SRC_T2       %11111110   ' Timer2 match PR2  output
$define TIMER_GATE_INT_OFF      %11111011   ' Interrupts disabled
$define TIMER_GATE_INT_ON       %11111111   ' Interrupts enabled
$endif

$if _defined (TMR_V4)
$define T34_SOURCE_CCP          %11111111   ' T3 and T4 are sources for CCP1 thru CCP5
$define T12_CCP12_T34_CCP345    %11110111   ' T1 and T2 are sources for CCP1 and CCP2 and T3 and T4 are sources for CCP3 thru CCP5
$define T12_CCP1_T34_CCP2345    %10111111   ' T1 and T2 are sources for CCP1 and T3 and T4 are sources for CCP2 thru CCP5
$define T12_SOURCE_CCP          %10110111   ' T1 and T2 are sources for CCP1 thru CCP5

$elseif _defined (TMR_V2)

$define T3_SOURCE_CCP           %11111111   ' T3 is source for CCP
$define T1_CCP1_T3_CCP2         %10111111   ' T1 is source for CCP1 and T3 is source for CCP2
$define T1_SOURCE_CCP           %10110111   ' T1 is source for CCP


$elseif _defined (TMR_V6)

$define T34_SOURCE_CCP12        %11111111   ' T3 and T4 are sources for CCP1 and CCP2
$define T12_CCP1_T34_CCP2       %11111101   ' T1 and T2 are sources for CCP1 and T3 and T4 are sources for CCP2
$define T12_SOURCE_CCP          %11111100   ' T1  and T2 is source for CCP1 and CCP2
$endif


$endif

