$ifndef _TimerMacroDef_
$define _TimerMacroDef_
'
' Timer Peripheral Macros
' For 18F devices using version 3.4.0.6 onwards of the Proton Compiler
' This file is supplied as-is and without warranty.
'
' It is encouraged that devices that are not supported be added by the users
' of the Proton compiler and made available on the Proton forum.
' www.protonbasic.co.uk
'
' However, do not Modify unless you are absolutely sure of what you are doing.
'

Include "TimerDefs.Inc"

(********************************************************************************)
$ifdef _TMR0L
'
' Timer0 Macros
'
' Create a word sized Timer0 for reading and writing
'
    Dim _Timer0M As TMR0L.Word
'---------------------------------------------------------------------------------
' Macro Name    : OpenTimer0
' Return Value  : None
' Parameters    : Bit definitions to configure Timer0
' Notes         : Reset the Timer0 regs to the POR state and configures the interrupt, clock source, edge and prescaler.
'               : The bit definitions for pConfig can be found in the TimerDefs.inc file.
'
$define OpenTimer0(pC) _OpenTimer0 pC

_OpenTimer0 Macro pConfig
    #if(Prm_Count != 1)
        #error "OpenTimer0 Macro requires a parameter"
        Exitm
    #endif
    #if((Prm_1 != Num8) && (Prm_1 != Num16) && (Prm_1 != Num32))
        #error "OpenTimer0 Macro parameter must be a constant value"
        Exitm
    #endif

    #if((0x7F & pConfig) == 0)
        Clear T0CON
    #else
        Num_SFR (0x7F & pConfig),T0CON  ' Configure timer0, but don't start it yet
    #endif
    Clear TMR0H                      ' Reset Timer0 to 0x0000
    Clear TMR0L
    Clear INTCONbits_T0IF            ' Clear Timer0 overflow flag
    #if(pConfig & 128)              ' If interrupts enabled
        Set INTCONbits_T0IE          ' Enable Timer0 overflow interrupt
    #else
        Clear INTCONbits_T0IE        ' Disable Timer0 overflow interrupt
    #endif
    Set T0CONbits_TMR0ON
    Endm
'---------------------------------------------------------------------------------
' Macro Name    : CloseTimer0
' Return Value  : None
' Parameters    : None
' Description   : Disable the Timer0 interrupt and stop Timer0
'
$define CloseTimer0() Clear INTCONbits_TMR0IE : T0CON = $7F

'---------------------------------------------------------------------------------
' Macro Name    : ReadTimer0
' Return Value  : Timer0 value
' Parameters    : None
' Description   : Read a value from Timer0.
'
$define ReadTimer0() _Timer0M
'
'---------------------------------------------------------------------------------
' Macro Name    : WriteTimer0
' Return Value  : None
' Parameters    : Value to write to Timer0
' Description   : Write a value to Timer0
'
$define WriteTimer0(pTimer) _Timer0M = pTimer
$endif
(********************************************************************************)
$ifdef _TMR1L
'
' Timer1 Macros
'
' Create a word sized Timer1 for reading and writing
'
    Dim _Timer1M As TMR1L.Word

'---------------------------------------------------------------------------------
' Macro Name    : OpenTimer1
' Return Value  : None
' Parameters    : Bit definitions to configure Timer1
' Notes         : Reset the Timer1 regs to the POR state and configures the interrupt, clock source, edge and prescaler.
'               : The bit definitions for pConfig can be found in the TimerDefs.Inc file.
'
$if _defined (TMR_V1) Or _defined (TMR_V2) Or _defined (TMR_V3)  Or  '
    _defined (TMR_V4) Or _defined (TMR_V5)

$define OpenTimer1(pC) _OpenTimer1 pC

_OpenTimer1 Macro pConfig
    #if(Prm_Count != 1)
        #error "OpenTimer1 Macro requires a parameter"
        Exitm
    #endif
    #if((Prm_1 != Num8) && (Prm_1 != Num16) && (Prm_1 != Num32))
        #error "OpenTimer1 Macro parameter must be a constant value"
        Exitm
    #endif
    #if((0x7E & pConfig) == 0)
        Clear T1CON
    #else
        Num_SFR (0x7E & pConfig),T1CON ' Configure timer1, but don't start it yet
    #endif
    #if(pConfig & 0x40)             ' The 8/16 selection bit isn't in the
        Set T1CONbits_RD16          ' right place so we need to move it
    #else
        Clear T1CONbits_RD16
    #endif
    Clear TMR1H                     ' Reset Timer1 to 0x0000
    Clear TMR1L
    Clear PIR1bits_TMR1IF           ' Clear Timer1 overflow flag
    #if(pConfig & 128)             ' If interrupts enabled
        Set PIE1bits_TMR1IE         ' Enable Timer1 overflow interrupt
    #else
        Clear PIE1bits_TMR1IE
    #endif
    Set T1CONbits_TMR1ON
    Endm
$endif

$if _defined (TMR_V6)

$define OpenTimer1(pC1, pC2) _OpenTimer1 pC1, pC2

_OpenTimer1 Macro pConfig, pConfig1
    #if(Prm_Count != 2)
        #error "OpenTimer1 Macro requires 2 parameters for this device"
        Exitm
    #endif
    #if((Prm_1 != Num8) && (Prm_1 != Num16) && (Prm_1 != Num32))
        #error "OpenTimer1 Macro parameter 1 must be a constant value"
        Exitm
    #endif
    #if((Prm_2 != Num8) && (Prm_2 != Num16) && (Prm_2 != Num32))
        #error "OpenTimer1 Macro parameter 2 must be a constant value"
        Exitm
    #endif

    Num_SFR (0xF3 & pConfig1),T1GCON
    Num_SFR ((0x7F & pConfig) << 1),T1CON

    Clear TMR1H                     ' Clear out timer registers
    Clear TMR1L
    Clear PIR1bits_TMR1IF           ' Clear Timer1 overflow flag
    #if(pConfig & 128)             ' If interrupts enabled
        Set PIE1bits_TMR1IE         ' Enable Timer1 overflow interrupt
    #else
        Clear PIE1bits_TMR1IE
    #endif
    Btfsc T1GCONbits_TMR1GE
    Set T1GCONbits_T1GGO
    Set T1CONbits_TMR1ON            ' Start Timer1
Endm
$endif
'---------------------------------------------------------------------------------
' Macro Name     : CloseTimer1
' Return Value   : None
' Parameters     : None
' Description    : Disable the Timer1 interrupt and stop Timer0
'
$define CloseTimer1() Clear T1CONbits_TMR1ON : Clear PIE1bits_TMR1IE

'---------------------------------------------------------------------------------
' Macro Name     : ReadTimer1
' Return Value   : Timer1 value
' Parameters     : None
' Description    : Read a value from Timer1
'
$define ReadTimer1() _Timer1M

'---------------------------------------------------------------------------------
' Macro Name     : WriteTimer1
' Return Value   : None
' Parameters     : Value to write to Timer1
' Description    : Write a value to Timer1
'
$define WriteTimer1(pTimer) _Timer1M = pTimer

$endif
(********************************************************************************)
$ifdef _TMR2
'
' Timer2 Macros
'
'---------------------------------------------------------------------------------
' Macro Name    : OpenTimer2
' Return Value  : None
' Parameters    : Bit definitions to configure Timer2
' Notes         : Reset the Timer2 regs to the POR state and configures the interrupt, clock source, edge and prescaler.
'               : The bit definitions for pConfig can be found in the TimerDefs.Inc file.
'
$define OpenTimer2(pC) _OpenTimer2 pC

_OpenTimer2 Macro pConfig
    #if(Prm_Count != 1)
        #error "OpenTimer2 Macro requires a parameter"
        Exitm
    #endif
    #if((Prm_1 != Num8) && (Prm_1 != Num16) && (Prm_1 != Num32))
        #error "OpenTimer2 Macro parameter must be a constant value"
        Exitm
    #endif
    #if((0xFB & pConfig) == 0)
        Clear T2CON
    #else
        Num_SFR (0xFB & pConfig),T2CON  ' Configure Timer2, but don't start it yet
    #endif
    Clear TMR2                      ' Reset Timer2 to 0x00
    Clear PIR1bits_TMR2IF           ' Clear Timer2 overflow flag
    #if(pConfig & 128)             ' If interrupts enabled
        Set PIE1bits_TMR2IE         ' Enable Timer2 overflow interrupt
    #else
        Clear PIE1bits_TMR2IE       ' Disable Timer2 overflow interrupt
    #endif
    Set T2CONbits_TMR2ON            ' Enable Timer2
    Endm
'---------------------------------------------------------------------------------
' Macro Name    : CloseTimer2
' Return Value  : None
' Parameters    : None
' Description   : Disable the Timer2 interrupt and stop Timer2
'
$define CloseTimer2() Clear T2CONbits_TMR2ON : Clear PIE1bits_TMR2IE

'---------------------------------------------------------------------------------
' Macro Name    : ReadTimer2
' Return Value  : Timer2 value
' Parameters    : None
' Description   : Read a value from Timer2.
'
$define ReadTimer2() TMR2

'---------------------------------------------------------------------------------
' Macro Name      : WriteTimer2
' Return Value    : None
' Parameters      : Value to write to Timer2
' Description     : Write a value to Timer2
'
$define WriteTimer2(pTimer) TMR2 = pTimer

$endif
(********************************************************************************)
$ifdef _TMR3L
'
' Timer3 Macros
'
    Dim _Timer3M As TMR3L.Word
'---------------------------------------------------------------------------------
' Macro Name    : T3_OSC1EN_ON
' Overview      : Sets the T1OSCEN bit in the T1CON
' Parameters    : None
' Remarks       : None.
$define T3_OSC1EN_ON() T1CONbits_T1OSCEN = 1      ' Timer 3 oscillator enables

'---------------------------------------------------------------------------------
' Macro name    : T3_OSC1EN_OFF
' Overview      : Clears the T1OSCEN bit in the T1CON
' Parameters    : None
' Remarks       : None
$define T3_OSC1EN_OFF() T1CONbits_T1OSCEN = 0     ' Timer 3 oscillator Disables

'---------------------------------------------------------------------------------
' Macro Name    : OpenTimer3
' Return Value  : None
' Parameters    : config: bit definitions to configure Timer3
' Description   : This routine first resets the Timer3 regs to the POR state and then configures the interrupt, clock source.
' Notes         : The bit definitions for config can be found in the TimerDefs.inc file.
'
$if _defined (TMR_V2) Or _defined (TMR_V4)

$define OpenTimer3(pC) _OpenTimer3 pC

_OpenTimer3 Macro pConfig
    #if(Prm_Count != 1)
        #error "OpenTimer3 Macro requires a parameter"
        Exitm
    #endif
    #if((Prm_1 != Num8) && (Prm_1 != Num16) && (Prm_1 != Num32))
        #error "OpenTimer3 Macro parameter must be a constant value"
        Exitm
    #endif
    #if((0x7E & pConfig) == 0)
        Clear T3CON
    #else
        Num_SFR (0x7E & pConfig),T3CON ' Set everything except 8/16 mode, and don't start timer yet
    #endif
    Clear TMR3H                       ' Clear timer3-related registers
    Clear TMR3L
    Clear PIR2bits_TMR3IF
    #if(pConfig & 128)               ' Interrupt on/off
        Set PIE2bits_TMR3IE
    #else
        Clear PIE2bits_TMR3IE
    #endif
    #if(pConfig & 2)
        Set T1CONbits_T1OSCEN         ' Enable Timer 1 Oscillator enable (200KHz max freq)
    #endif
    #if(pConfig & ~T3_8BIT_RW)        ' Select between 8-bit and 16-bit modes
        Set T3CONbits_RD16
    #else
        Clear T3CONbits_RD16
    #endif
    Set T3CONbits_TMR3ON              ' Turn on Timer3
    Endm
$endif
$if _defined (TMR_V6)

$define OpenTimer3(pC, pC1) _OpenTimer3 pC, pC1

_OpenTimer3 Macro pConfig, pConfig1
    #if(Prm_Count != 2)
        #error "OpenTimer3 Macro requires 2 parameters for this device"
        Exitm
    #endif
    #if((Prm_1 != Num8) && (Prm_1 != Num16) && (Prm_1 != Num32))
        #error "OpenTimer3 Macro parameter 1 must be a constant value"
        Exitm
    #endif
    #if((Prm_2 != Num8) && (Prm_2 != Num16) && (Prm_2 != Num32))
        #error "OpenTimer3 Macro parameter 2 must be a constant value"
        Exitm
    #endif
    Num_SFR(0XF3 & pConfig1),T3GCON
    Num_SFR((0x7F & pConfig) << 1),T3CON ' Set everything except 8/16 mode, and don't start timer yet

    Clear TMR3H                         ' Clear timer3-related registers
    Clear TMR3L
    Clear PIR2bits_TMR3IF
    Clear PIR3bits_TMR3GIF

    #if(pConfig & 128)                 ' Interrupt on/off
        Set PIE2bits_TMR3IE
    #else
        Clear PIE2bits_TMR3IE
    #endif
    #if(pConfig1 & 4)
        Set PIE3bits_TMR3GIE
    #else
        Clear PIE3bits_TMR3GIE
    #endif

    Btfsc T3GCONbits_TMR3GE
    Set T3GCONbits_T3GGO

    Set T3CONbits_TMR3ON                ' Turn on Timer3
Endm
$endif
'---------------------------------------------------------------------------------
' Macro Name    : CloseTimer3
' Return Value  : None
' Parameters    : None
' Description   : Disable the Timer3 interrupt and stop Timer0
'
$if _defined (TMR_V2) Or _defined (TMR_V4)
$define CloseTimer3() Clear T3CONbits_TMR3ON : Clear PIE2bits_TMR3IE
$endif
$if _defined (TMR_V6)
$define CloseTimer3() Clear T3CONbits_TMR3ON : Clear PIE2bits_TMR3IE : Clear PIE3bits_TMR3GIE
$endif
'---------------------------------------------------------------------------------
' Macro Name    : ReadTimer3
' Return Value  : Timer3 value
' Parameters    : None
' Description   : Read a value from Timer3.
'
$define ReadTimer3() _Timer3M

'---------------------------------------------------------------------------------
' Macro Name    : WriteTimer3
' Return Value  : None
' Parameters    : Value to write to Timer3
' Description   : Write a value to Timer3
'
$define WriteTimer3(pTimer) _Timer3M = pTimer

$endif
(********************************************************************************)
$ifdef _TMR4
'
' Timer4 Macros
'
'---------------------------------------------------------------------------------
' Macro Name    : OpenTimer4
' Return Value  : None
' Parameters    : Bit definitions to configure Timer4
' Notes         : Reset the Timer4 regs to the POR state and configures the interrupt, clock source, edge and prescaler.
'               : The bit definitions for pConfig can be found in the TimerDefs.Inc file.
'
$define OpenTimer4(pC) _OpenTimer4 pC

_OpenTimer4 Macro pConfig
    #if(Prm_Count != 1)
        #error "OpenTimer4 Macro requires a parameter"
        Exitm
    #endif
    #if((Prm_1 != Num8) && (Prm_1 != Num16) && (Prm_1 != Num32))
        #error "OpenTimer4 Macro parameter must be a constant value"
        Exitm
    #endif
    #if((0xFB & pConfig) == 0)
        Clear T4CON
    #else
        Num_SFR (0xFB & pConfig),T4CON ' Configure Timer4, but don't start it yet
    #endif
    Clear TMR4                      ' Reset Timer4
    Clear PIR3bits_TMR4IF           ' Clear Timer4 overflow flag
    #if(pConfig & 128)             ' If interrupts enabled
        Set PIE3bits_TMR4IE         ' Enable Timer4 overflow interrupt
    #else
        Clear PIE3bits_TMR4IE
    #endif
    Set T4CONbits_TMR4ON            ' Enable Timer4
    Endm
'---------------------------------------------------------------------------------
' Macro Name    : CloseTimer4
' Return Value  : None
' Parameters    : None
' Description   : Disable the Timer4 interrupt and stop Timer4
'
$define CloseTimer4() Clear T4CONbits_TMR4ON : Clear PIE3bits_TMR4IE

'---------------------------------------------------------------------------------
' Macro Name    : ReadTimer4
' Return Value  : Timer4 value
' Parameters    : None
' Description   : Read a value from Timer4.
'
$define ReadTimer4() TMR4

'---------------------------------------------------------------------------------
' Macro Name    : WriteTimer4
' Return Value  : None
' Parameters    : Value to write to Timer4
' Description   : Write a value to Timer4
'
$define WriteTimer4(pTimer) TMR4 = pTimer

$endif

'---------------------------------------------------------------------------------
$ifdef _TMR5L
'
' Timer5 Macros
'
    Dim _Timer5M As TMR5L.Word
'---------------------------------------------------------------------------------
' Macro Name    : OpenTimer5
' Return Value  : None
' Parameters    : Bit definitions to configure Timer5
' Notes         : Reset the Timer5 regs to the POR state and configures the interrupt, clock source, edge and prescaler.
'               : The bit definitions for pConfig can be found in the TimerDefs.Inc file.
'
$define OpenTimer5(pC,pT) _OpenTimer5 pC, pT

_OpenTimer5 Macro pConfig, pT5pr
    #if(Prm_Count != 2)
        #error "OpenTimer5 Macro requires 2 parameters"
        Exitm
    #endif
    #if((Prm_1 != Num8) && (Prm_1 != Num16) && (Prm_1 != Num32))
        #error "OpenTimer5 Macro parameter 1 must be a constant value"
        Exitm
    #endif
    #if((Prm_2 != Num8) && (Prm_2 != Num16) && (Prm_2 != Num32))
        #error "OpenTimer5 Macro parameter 2 must be a constant value"
        Exitm
    #endif

    Num_SFR(0xFE & pConfig),T5CON   ' Set all configuration values, but
                                    ' don't start timer yet
    TMR5H = 0
    TMR5L = 0                       ' Clear Timer5

    Num_SFR pT5pr,PR5L
    Num_SFR(pT5pr >> 8),PR5H

    PIR3bits_TMR5IF = 0

    #if(pConfig & 1)                ' Enable timer interrupts?
        PIE3bits_TMR5IE = 1
    #else
        PIE3bits_TMR5IE = 0
    #endif

    T5CONbits_TMR5ON = 1            ' Turn on Timer5
Endm
'---------------------------------------------------------------------------------
' Macro Name    : CloseTimer5
' Return Value  : None
' Parameters    : None
' Description   : Disable the Timer5 interrupt and stop Timer5
'
$define CloseTimer5() Clear T5CONbits_TMR5ON : Clear PIE3bits_TMR5IE

'---------------------------------------------------------------------------------
' Macro Name    : ReadTimer5
' Return Value  : Timer5 value
' Parameters    : None
' Description   : Read from Timer5.
'
$define ReadTimer5() _Timer5M

'---------------------------------------------------------------------------------
' Macro Name    : WriteTimer5
' Return Value  : None
' Parameters    : Value to write to Timer5
' Description   : Write to Timer5
'
$define WriteTimer5(pTimer) _Timer5M = pTimer

$endif

'---------------------------------------------------------------------------------
' Macro Name    : SetTmrCCPSrc
' Return Value  : None
' Parameters    : pConfig: bit definitions to configure Timer as a clock source to CCP module
' Description   : This routine configures the timer to work as a clock source to CCP module.
'               : Required timer has to be enabled by calling respective function.
' Notes         : The bit definitions for config can be found in the TimerDefs.inc file.

$if _defined (TMR_V2) Or _defined (TMR_V4)
$define SetTmrCCPSrc(pConfig) '
    T3CON  = T3CON & $B7      '
    WREG = pConfig & $48      '
    T3CON = T3CON | WREG
$endif

$if _defined (TMR_V6)
$define SetTmrCCPSrc(pConfig) '
    TCLKCON = TCLKCON & $FC   '
    WREG = pConfig & $03      '
    TCLKCON = TCLKCON | WREG
$endif
$endif
